/*
**  CXSC is a C++ library for eXtended Scientific Computing (V 2.1)
**
**  Copyright (C) 1990-2000 Institut fuer Angewandte Mathematik,
**                          Universitaet Karlsruhe, Germany
**            (C) 2000-2005 Wiss. Rechnen/Softwaretechnologie
**                          Universitaet Wuppertal, Germany   
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Library General Public
**  License as published by the Free Software Foundation; either
**  version 2 of the License, or (at your option) any later version.
**
**  This library is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
**  Library General Public License for more details.
**
**  You should have received a copy of the GNU Library General Public
**  License along with this library; if not, write to the Free
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* CVS $Id: imath.hpp,v 1.14 2005/12/19 17:46:33 cxsc Exp $ */

#ifndef imath_hpp_included
#define imath_hpp_included

#include "except.hpp"
#include "interval.hpp"

namespace cxsc {

interval sqr    (const interval&) throw();        // Sqr(x)
interval sqrt   (const interval&);        // Sqrt(x)
interval sqrt   (const interval &, int) throw(STD_FKT_OUT_OF_DEF);  // Sqrt(x, n)
interval sqrt1px2(const interval&) throw(); // Sqrt(1+x^2), Blomquist 13.12.02
interval sqrtp1m1(const interval&) throw(); // Sqrt(x+1)-1; Blomquist 05.08.03
interval sqrtx2m1(const interval&);         // sqrt(x^2-1);  Blomquist, 13.04.04;
interval sqrt1mx2(const interval&);         // sqrt(1-x^2);  Blomquist, 13.04.04;

interval sin    (const interval&) throw();        // Sin(x)
interval cos    (const interval&) throw();        // Cos(x)
interval tan    (const interval&) throw();        // Tan(x)
interval cot    (const interval&) throw();        // Cot(x)

interval asin   (const interval&);        // ASin(x)
interval acos   (const interval&);        // ACos(x)
interval atan   (const interval&);        // ATan(x) 
interval acot   (const interval&);        // ACot(x)


interval exp    (const interval&) throw();        // Exp(x)
interval expmx2 (const interval&);         // Exp(-x^2)
interval ln     (const interval&);         // Ln(x)
interval lnp1   (const interval&) throw(); // Ln(1+x), Blomquist 21.12.02

interval sinh   (const interval&) throw();        // Sinh(x)
interval cosh   (const interval&) throw();        // Cosh(x)
interval tanh   (const interval&) throw();        // Tanh(x) 
interval coth   (const interval&) throw();        // Coth(x)

interval asinh  (const interval&);        // ASinh(x)
interval acosh  (const interval&);        // ACosh(x)
interval acoshp1(const interval& x);      // acosh(1+x)
interval atanh  (const interval&);        // ATanh(x)
interval acoth  (const interval&);        // ACoth(x)

interval erf    (const interval&);        // error function
interval erfc   (const interval&);        // complementary error function

// interval pow    (const interval&, const interval&) throw(ERROR_INTERVAL_STD_FKT_OUT_OF_DEF);  // Pow(x,y)
interval pow    (const interval&, const interval&) throw();  // Pow(x,y)
interval power  (const interval&, int);    // Power(x,n)
interval Power  (const interval&, int);    // Power(x,n)

interval sqrtx2y2(const interval&, 
                const interval&) throw(); // Sqrt(x^2+y^2), Blomquist 13.12.02
interval ln_sqrtx2y2(const interval&, const interval&) throw();
                                  // ln( sqrt(x^2+y^2) ) == 0.5*ln(x^2+y^2);
interval Pi         ( );
} // namespace cxsc 

// #include "imath.inl"

#endif





